@@ -24,7 +24,7 @@ import requests_mock
 import transaction
 
 
-class TestContact(ImioSmartwebTestCase):
+class TestSectionContact(ImioSmartwebTestCase):
 
     layer = IMIO_SMARTWEB_CORE_FUNCTIONAL_TESTING
 
@@ -105,13 +105,16 @@ class TestContact(ImioSmartwebTestCase):
         self.assertNotIn("contact_description", view())
         contact.visible_blocks = ["description"]
         self.assertIn("contact_description", view())
-        self.assertIn("Super description", view())
+        self.assertIn(
+            "Description &lt;strong&gt;avec gras&lt;/strong&gt; et &lt;br/&gt; retours à la ligne",
+            view(),
+        )
 
         contact.visible_blocks = ["titles", "gallery"]
         m.get(contact_images_url, text=json.dumps(self.json_contact_images))
         clear_cache(self.request)
         self.assertIn("contact_gallery", view())
-        self.assertEqual(len(contact_view.images), 2)
+        self.assertEqual(len(contact_view.images[0]), 2)
 
         m.get(contact_search_url, exc=requests.exceptions.ConnectTimeout)
         clear_cache(self.request)
@@ -256,6 +259,9 @@ class TestContact(ImioSmartwebTestCase):
             "afternoonend": "",
             "comment": "",
         }
+        with freeze_time("2021-09-14 7:30:00"):
+            result = get_schedule_for_today(schedule)
+            self.assertEqual("Open at  08:30", result)
         with freeze_time("2021-09-14 8:00:00"):
             result = get_schedule_for_today(schedule)
             self.assertIn("Open at", result)
